@@ -1,8 +1,8 @@
-import re
-from pprint import pprint
-from typing import Dict, List, Optional, Union
 import json
-import logging
+import re
+
+from typing import Dict, List, Optional
+
 TIMESTAMP_REGEX = "(\d{4}-\d?\d-\d?\d)T((?:2[0-3]|[01]?[0-9]):[0-5]?[0-9]:[0-5]?[0-9])Z$"  # Regex to detect timestamps
 INTEGER = "[0-9]+$"
 
@@ -27,13 +27,11 @@ def _expand_list_values(json_list: list, ignore_types: List[type] = [], ignore_r
     return elements
 
 
-def filter_values(dictionary: Dict,
-                  ignore_types: List[type] = [],
-                  ignore_regex: Optional[dict] = None) -> Dict[str, type]:
+def filter_values(dictionary: Dict, ignore_types: List[type] = [], ignore_regex: Optional[dict] = None) -> Dict[str, type]:
     """
     Extract types from (eventually nested) dictionary.
 
-    :param dictionary: Input dictionary to etract types from.
+    :param dictionary: Input dictionary to extract types from.
     :param ignore_types: Optional list of types to be ignored when found.
     :param ignore_regex: Optional regex string to be ignored when matched.
     :return: A dictionary with types instead of proper values.
@@ -58,12 +56,9 @@ def filter_values(dictionary: Dict,
     return dict_types
 
 
-def dict_diff(actual: Dict,
-              expected: Dict,
-              ignore_types: List[type] = [],
-              ignore_regex: Optional[dict] = None) -> Dict[str, type]:
+def dict_diff(actual: Dict, expected: Dict, ignore_types: List[type] = [], ignore_regex: Optional[dict] = None) -> Dict[str, type]:
     """
-    Compute differencies in two dictionary composition types.
+    Compute differences in two dictionary composition types.
 
     :param actual: The dictionary to be compared.
     :param expected: The reference dictionary.
@@ -72,13 +67,9 @@ def dict_diff(actual: Dict,
     :return: A dictionary containing only differing keys and motivation as value.
     """
     # Adapt value from input dict
-    actual_types = filter_values(actual,
-                                 ignore_types=ignore_types,
-                                 ignore_regex=ignore_regex)
+    actual_types = filter_values(actual, ignore_types=ignore_types, ignore_regex=ignore_regex)
     # Adapt value from expected dict
-    expected_types = filter_values(expected,
-                                   ignore_types=ignore_types,
-                                   ignore_regex=ignore_regex)
+    expected_types = filter_values(expected, ignore_types=ignore_types, ignore_regex=ignore_regex)
 
     def _get_diff(actual_types: Dict, expected_types: Dict) -> Dict[str, type]:
         """
@@ -139,14 +130,9 @@ def dict_diff(actual: Dict,
 
 # Diff
 def json_compare(actual, expected, ignore_regex1=[TIMESTAMP_REGEX, INTEGER]):
-    # actual = json.load(open(actual, "r"))  # Sample dictionary to be validated
-    print(ignore_regex1)
     ignore_regex = '(?:% s)' % '|'.join((str(regex) for regex in ignore_regex1))
     expected = json.load(open(expected, "r"))  # Sample dictionary to be validated
-    print(ignore_regex1)
     differenceJson = dict_diff(actual, expected, ignore_regex=ignore_regex)
-    # differenceJson = dict_diff(actual, expected, ignore_regex)
-    print(differenceJson)
     result = bool(differenceJson)
     if result:
         print("Diffs found:", result)
@@ -155,38 +141,18 @@ def json_compare(actual, expected, ignore_regex1=[TIMESTAMP_REGEX, INTEGER]):
     assert result is False
 
 
-# Diff ignoring types
-# pprint(dict_diff(actual, expected, ignore_types=[int, bool]))
-# Diff ignoring timestamp regex
-# pprint(dict_diff(actual, expected, ignore_regex=TIMESTAMP_REGEX))
-
-# jsonCompare(ACTUAL_FILE_PATH, EXPECTED_FILE_PATH)
-
-# pprint(dict_diff(actual, expected, ignore_regex=[TIMESTAMP_REGEX,INTEGER]))
-
-
-
 def json_compare_dictionary(actual, expected, ignore_regex1=[TIMESTAMP_REGEX, INTEGER]):
-    # actual = json.load(open(actual, "r"))  # Sample dictionary to be validated
-    print(ignore_regex1)
     ignore_regex = '(?:% s)' % '|'.join((str(regex) for regex in ignore_regex1))
-
-    print(ignore_regex1)
     differenceJson = dict_diff(actual, expected, ignore_regex=ignore_regex)
-    # differenceJson = dict_diff(actual, expected, ignore_regex)
-    print(differenceJson)
     result = bool(differenceJson)
     if result:
         print("Diffs found:", result)
     else:
         print("No diff found!")
     assert result is False
-    
-    
-  
-def schema_extract_types(dictionary: Dict,
-                         ignore_types: List[type] = [],
-                         ignore_regex: Optional[str] = None) -> Dict[str, type]:
+
+
+def schema_extract_types(dictionary: Dict, ignore_types: List[type] = [], ignore_regex: Optional[str] = None) -> Dict[str, type]:
     """
     Extract types from (eventually nested) dictionary.
 
@@ -209,12 +175,9 @@ def schema_extract_types(dictionary: Dict,
     return dict_types
 
 
-def schema_dict_diff(actual: Dict,
-                     expected: Dict,
-                     ignore_types: List[type] = [],
-                     ignore_regex: Optional[str] = None) -> Dict[str, type]:
+def schema_dict_diff(actual: Dict, expected: Dict, ignore_types: List[type] = [], ignore_regex: Optional[str] = None) -> Dict[str, type]:
     """
-    Compute differencies in two dictionary composition types.
+    Compute differences in two dictionary composition types.
 
     :param actual: The dictionary to be compared.
     :param expected: The reference dictionary.
@@ -223,13 +186,9 @@ def schema_dict_diff(actual: Dict,
     :return: A dictionary containing only differing keys and motivation as value.
     """
     # Extract types from actual dict
-    actual_types = schema_extract_types(actual,
-                                        ignore_types=ignore_types,
-                                        ignore_regex=ignore_regex)
+    actual_types = schema_extract_types(actual, ignore_types=ignore_types, ignore_regex=ignore_regex)
     # Extract types from expected dict
-    expected_types = schema_extract_types(expected,
-                                          ignore_types=ignore_types,
-                                          ignore_regex=ignore_regex)
+    expected_types = schema_extract_types(expected, ignore_types=ignore_types, ignore_regex=ignore_regex)
 
     def schema_get_diff(actual_types: Dict, expected_types: Dict) -> Dict[str, type]:
         """
@@ -275,7 +234,6 @@ def schema_dict_diff(actual: Dict,
 def json_compare_schema(actual, expected, ignore_regex=TIMESTAMP_REGEX):
     expected = json.load(open(expected, "r"))  # Sample dictionary to be validated
     differenceJson = schema_dict_diff(actual, expected, ignore_regex=TIMESTAMP_REGEX)
-    print(differenceJson)
     result = bool(differenceJson)
     if result:
         print("Diffs found:", result)
