@@ -2,21 +2,22 @@ import json
 import logging
 import requests
 from FunctionalTests.FunctionalParam import FunctionalParam
-# from jsonpath_ng import jsonpath, parse
 
 functionalParm = FunctionalParam()
 logger = logging.getLogger()
 logger.setLevel(logging.DEBUG)
 
 try:
-	from Config.Defaultheader import Defaultheader
-	header = Defaultheader()
+    from Config.Defaultheader import Defaultheader
+
+    header = Defaultheader()
 except:
-	pass
+    pass
 
 stagelink = "ifi/151613/"
 endpoint = "https://plutus.mum1-stage.zeta.in/plutus-onboarding/send/otp"
-file_name="endPointUserConf.json"
+file_name = "endPointUserConf.json"
+
 
 def get_stage():
     with open(file_name) as json_file:
@@ -35,23 +36,22 @@ class Utilities(object):
         endpoint = endpoint
 
         requests.request("GET", endpoint, headers=functionalParm.getHeader("defaultUser"))
-    
-    
+
     def check_status_code_turbo(self,
-                          endPoint=None,
-                          requestMethod="GET",
-                          user="Captain_America",
-                          params=None,
-                          expectedStatusCode=requests.codes.ok,
-                          jsonPayload=None,
-                          token=None,envFile=None):
-        if token!= None:
+                                endPoint=None,
+                                requestMethod="GET",
+                                user="Captain_America",
+                                params=None,
+                                expectedStatusCode=requests.codes.ok,
+                                jsonPayload=None,
+                                token=None, envFile=None):
+        if token != None:
             headers = {'Content-Type': 'application/json',
-                      'X-Zeta-AuthToken': token}
+                       'X-Zeta-AuthToken': token}
         elif user == "userAuthToken":
-            headers = functionalParm.getHeaderClearRateLImit(user,envFile)
+            headers = functionalParm.getHeaderClearRateLImit(user, envFile)
         elif user == "userStaticToken":
-            headers = functionalParm.getTokenCardApplication(user,envFile)
+            headers = functionalParm.getTokenCardApplication(user, envFile)
         elif user == "user3":
             headers = header.createIDHeaders(envFile)
         elif user == "UpdateStatusUser":
@@ -59,12 +59,12 @@ class Utilities(object):
         elif user == "ganymedeUser":
             headers = header.ganymedeHeaders(envFile)
         elif user != 'null':
-            headers = functionalParm.getHeader(user,envFile)
+            headers = functionalParm.getHeader(user, envFile)
         else:
             headers = None
 
         if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
-            endpoint = endPoint.replace("ifi/151613", "fi/13")
+            endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
@@ -72,42 +72,35 @@ class Utilities(object):
         logger.info(response.json())
         return response
         pass
-        
-        
-        
+
     def check_status_code_no_response_body(self,
-                          endPoint=None,
-                          requestMethod="GET",
-                          user="Captain_America",
-                          params=None,
-                          expectedStatusCode=requests.codes.ok,
-                          jsonPayload=None, token=None,envFile=None):
-        if token!= None:
+                                           endPoint=None,
+                                           requestMethod="GET",
+                                           user="Captain_America",
+                                           params=None,
+                                           expectedStatusCode=requests.codes.ok,
+                                           jsonPayload=None, token=None, envFile=None):
+        if token != None:
             headers = {'Content-Type': 'application/json',
-                      'X-Zeta-AuthToken': token}
+                       'X-Zeta-AuthToken': token}
         elif user == "userStaticToken":
-            headers = functionalParm.getTokenCardApplication(user,envFile)
+            headers = functionalParm.getTokenCardApplication(user, envFile)
         elif user != 'null':
-            headers = functionalParm.getHeader(user,envFile)
+            headers = functionalParm.getHeader(user, envFile)
         else:
             headers = None
 
         if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
-            endpoint = endPoint.replace("ifi/151613", "fi/13")
+            endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
 
-    def assert_error_message(self,response,errorKey,errorMessage):
+    def assert_error_message(self, response, errorKey, errorMessage):
         if response:
             assert response.json().get(errorKey) == errorMessage
 
-    def assert_error_message(self,response,errorKey,errorMessage):
-        if response:
-            assert response.json().get(errorKey) == errorMessage
-        
-        
     def check_status_code(self,
                           endPoint=None,
                           requestMethod="GET",
@@ -120,7 +113,7 @@ class Utilities(object):
         else:
             headers = None
 
-        if ((endPoint.find(stagelink) != -1) and (get_stage()=='beta')):
+        if (endPoint.find(stagelink) != -1) and (get_stage() == 'beta'):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         logger.info(f"status code{response.status_code}")
@@ -142,10 +135,10 @@ class Utilities(object):
         else:
             headers = None
 
-        if ((endPoint.find(stagelink) != -1) and (get_stage()=='beta')):
+        if (endPoint.find(stagelink) != -1) and (get_stage() == 'beta'):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
-        logger.info(f"status code{ response.status_code}")
+        logger.info(f"status code{response.status_code}")
         assert response.status_code == expectedStatusCode, \
             "Expected and Actual status code did not match"
         logger.info(response.json())
@@ -163,17 +156,16 @@ class Utilities(object):
 
     def db_validation(self):
         raise NotImplementedError("not implemented")
-        
-        
-    def check_status_code_with_custom_header(self,
-                          endPoint=None,
-                          requestMethod="GET",
-                          headers=None,
-                          params=None,
-                          expectedStatusCode=requests.codes.ok,
-                          jsonPayload=None):
 
-        if ((endPoint.find(stagelink) != -1) and (get_stage()=='beta')):
+    def check_status_code_with_custom_header(self,
+                                             endPoint=None,
+                                             requestMethod="GET",
+                                             headers=None,
+                                             params=None,
+                                             expectedStatusCode=requests.codes.ok,
+                                             jsonPayload=None):
+
+        if (endPoint.find(stagelink) != -1) and (get_stage() == 'beta'):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         logger.info(f"status code{response.status_code}")
